@@ -8,11 +8,11 @@ use utf8;
 use integer;
 
 use Carp;
-use List::MoreUtils qw(all part);
+use List::Util qw(all);
 
 use vars qw ($VERSION);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 
 my $DELTA = 0x9e3779b9;
@@ -58,9 +58,9 @@ sub encrypt {
     my $self = shift;
     my $plain_text = shift;
     croak( sprintf( 'block size must be %d', $BLOCK_SIZE) ) if length($plain_text) != $BLOCK_SIZE;
-    my @block = unpack 'I>*', $plain_text;
+    my @block = unpack 'N*', $plain_text;
     my $cipher_text_ref = $self->encrypt_block( \@block );
-    return pack( 'I>*', @{$cipher_text_ref} );
+    return pack( 'N*', @{$cipher_text_ref} );
 }
 
 
@@ -68,9 +68,9 @@ sub decrypt {
     my $self = shift;
     my $cipher_text = shift;
     croak( sprintf( 'block size must be %d', $BLOCK_SIZE) ) if length($cipher_text) != $BLOCK_SIZE;
-    my @block = unpack 'I>*', $cipher_text;
+    my @block = unpack 'N*', $cipher_text;
     my $plain_text_ref = $self->decrypt_block( \@block );
-    return pack( 'I>*', @{$plain_text_ref} );
+    return pack( 'N*', @{$plain_text_ref} );
 }
 
 sub encrypt_block {
@@ -85,13 +85,12 @@ sub encrypt_block {
     my @key = map { $_ & 0xffff_ffff } @{ $key_ref };
     my $sumation = 0 & 0xffff_ffff;
     my $delta = $DELTA & 0xffff_ffff;
-        printf("\t--> block[0] = %d, block[1] = %d\n", $block[0], $block[1]);
     for my $i ( 0 .. $self->{rounds}-1 ) {
         $sumation = ( $sumation + $delta ) & 0xffff_ffff;
         $block[0] = ( $block[0] + ( ( ( ( ( ( ( ( $block[1] << 4 ) & 0xffff_ffff ) + $key[0] ) & 0xffff_ffff ) ^ ( ( $block[1] + $sumation ) & 0xffff_ffff ) ) & 0xffff_ffff ) ^ ( ( ( ( $block[1] >> 5 ) & 0xffff_ffff ) +  $key[1] ) & 0xffff_ffff ) ) & 0xffff_ffff ) ) & 0xffff_ffff;
         $block[1] = ( $block[1] + ( ( ( ( ( ( ( ( $block[0] << 4 ) & 0xffff_ffff ) + $key[2] ) & 0xffff_ffff ) ^ ( ( $block[0] + $sumation ) & 0xffff_ffff ) ) & 0xffff_ffff ) ^ ( ( ( ( $block[0] >> 5 ) & 0xffff_ffff ) +  $key[3] ) & 0xffff_ffff ) ) & 0xffff_ffff ) ) & 0xffff_ffff;
         #printf("\t--> Encrypting block round %d of %d\n", $i + 1, $ROUNDS);
-        #printf("\t--> block[0] = %d, block[1] = %d\n", $block[0], $block[1]);
+        printf("\t--> block[0] = %d, block[1] = %d\n", $block[0], $block[1]);
     }
     return \@block;
 }
@@ -121,8 +120,7 @@ sub decrypt_block {
 sub key_setup {
     my $key_str = shift;
     croak( sprintf( 'key must be %s bytes long', $KEY_SIZE ) ) if length( $key_str ) != $KEY_SIZE;
-    my @key_arr = split '', $key_str;
-    my @tea_key = map { unpack( 'I>*', join('', @{$_}) ) } map { [ map { $key_arr[$_] } @{$_} ] } part { int( $_ / 4 ) } keys @key_arr;
+    my @tea_key = unpack 'N*', $key_str;
     return \@tea_key;
 }
 
@@ -141,7 +139,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.02
+version 0.0201
 
 =head1 SYNOPSIS
 
